'LineInfo.csc
'Displays line position and dimension info (by Abe Hendin)
'Copyright 2001-2003 by Abe Hendin <ventura@yourspeed.com>. Public Domain.
'Version 1.02
'October 14, 2003
'
'Displays various measurements of a line relative to the margins
'of the base page frame, in points. Very basic script (1.0 was an 
'early example of my scripting; somewhat better now, but one day 
'I'll design a bitmap to show the info graphically).
'
'VERSION HISTORY:
'1.01: does away with LENGTHCONVERT() and converts "manually"
'for a more accurate conversion. I seem to recall that I found 
'LENGTHCONVERT() to be somewhat less than accurate, but I now 
'forget the details. Eventually I'll write my own conversion 
'function, but that's for another day...
'Also, got rid of the insertion/find/deletion of text string to 
'pinpoint location, much cleaner to use .TextFileSelectGet!
'
'1.02: Added a function to do the units conversion; cleans up the 
'code some.

#DEFINE TM_PT			3527.7778

DECLARE FUNCTION sPointsHundredths(lToConvert AS LONG) AS STRING

DIM lLeftPos AS LONG, lTopPos AS LONG, lWidth AS LONG
DIM lHeight AS LONG, lBaseLineYPos AS LONG
DIM lLMargin AS LONG, lRMargin AS LONG, lTMargin AS LONG, lBMargin AS LONG
DIM sTopPosCPts AS STRING, sWidthPts AS STRING, lTCapTIlineDiff AS LONG
DIM sTopPosIPts AS STRING, sBaseLinePts AS STRING, sLinelHeightC AS STRING
DIM sLinelHeightI AS STRING, sLeftPosPts AS STRING, sRightPosPts AS STRING

DIM sFileName AS STRING, lParaNum AS LONG, lCharNum AS LONG

DIM sBound AS STRING, sIntro AS STRING, sTI AS STRING, sTC AS STRING
DIM sB AS STRING, sHI AS STRING, sHC AS STRING, sL AS STRING
DIM sW AS STRING, sM AS STRING, sE AS STRING

DIM iret AS INTEGER

REM BEGIN DIALOG OBJECT LineInfoDlg 329, 253, "Line Information"
REM END DIALOG
REM 

WITHOBJECT "CorelVentura.Automation.8"
	'gathers the line info, and sets a marker to enable returning to
	'the starting point at the conclusion of the script
	.TextLineInfoGet , , , lLeftPos, lTopPos, lWidth, lHeight, lBaseLineYPos
	
	'get current cursor pos
	.TextFileSelectGet sFileName, lParaNum, lCharNum
	
	'gets the page margins to calculate position from margin
	.FrameFirst .BaseFrame = TRUE
	.FormatFrameMarginsInsideGet , lLMargin, lRMargin, lTMargin, lBMargin
	
	'return cursor to starting point
	.TextFileSelect sFileName, lParaNum, lCharNum
END WITHOBJECT

'converts Ventura units (tenths of a micron) to points; round to 2 places
sTopPosCPts = sPointsHundredths(lTopPos - lTMargin)
sWidthPts = sPointsHundredths(lWidth)
lTCapTIlineDiff = lTopPos - lBaseLineYPos + lHeight
sTopPosIPts = sPointsHundredths(lTopPos - lTMargin - lTCapTIlineDiff)
sBaseLinePts = sPointsHundredths(lBaseLineYPos - lTMargin)
sLinelHeightC = sPointsHundredths(lBaseLineYPos - lTopPos)
sLinelHeightI = sPointsHundredths(lHeight)
sLeftPosPts = sPointsHundredths(lLeftPos - lLMargin)
sRightPosPts = sPointsHundredths(lWidth + lLeftPos - lLMargin)

'This section displays the info.
sBound = "--------------------------------------------------" + \\
	"------------------------------------------------- "
sIntro = "  Values in points, rounded to 2 decimal places; " + \\
	"positions relative to page margins. "
sTI = "Top of Line (Interline): "
sTC = "                   (Cap Top): "
sB = "Baseline Position: "
sHI = "Line Height (Interline): "
sHC = "                          (Cap): "
sL = "Start of Line: "
sW = "Line Width: "
sM = "Middle of Line: "
sE = "End of Line: "

iret = MESSAGEBOX(sBound + \\
	CHR(13) + sIntro + \\
	CHR(13) + sBound + \\
	CHR(13) + \\
	CHR(13) + sTI + sTopPosIPts + \\
	CHR(13) + sTC + sTopPosCPts + \\
	CHR(13) + sB + sBaseLinePts + \\
	CHR(13) + \\
	CHR(13) + sHI + sLinelHeightI + \\
	CHR(13) + sHC + sLinelHeightC + \\
	CHR(13) + sW + sWidthPts + \\
	CHR(13) + \\
	CHR(13) + sL + sLeftPosPts + \\
	CHR(13) + sE + sRightPosPts, \\
	"Line Information", 0)

FUNCTION sPointsHundredths(lToConvert AS LONG) AS STRING
	sPointsHundredths = LTRIM(STR(INT((CDBL(lToConvert)/TM_PT)*100+.5)/100))
END FUNCTION

